@@ -1,9 +1,7 @@
 """JSON helper functions"""
-try:
-    import simplejson as json
-except ImportError:
-    import json
+import json
 
+from django.core.serializers.json import DjangoJSONEncoder
 from django.http import HttpResponse
 
 
@@ -16,7 +14,7 @@ def JsonResponse(data, dump=True, status=200):
         pass
 
     return HttpResponse(
-        json.dumps(data) if dump else data,
+        json.dumps(data, cls=DjangoJSONEncoder) if dump else data,
         content_type='application/json',
         status=status,
     )
@@ -27,7 +25,7 @@ def JsonError(error_string, status=200):
         'success': False,
         'errors': error_string,
     }
-    return JSONResponse(data)
+    return JsonResponse(data, status=status)
 
 
 def JsonResponseBadRequest(error_string):
@@ -52,8 +50,3 @@ def JsonResponseNotAllowed(error_string):
 
 def JsonResponseNotAcceptable(error_string):
     return JsonError(error_string, status=406)
-
-
-# For backwards compatability purposes
-JSONResponse = JsonResponse
-JSONError = JsonError
